@@ -5,8 +5,8 @@
 ;; Author: Adam Porter <adam@alphapapa.net>
 ;; Maintainer: Adam Porter <adam@alphapapa.net>
 ;; URL: https://github.com/alphapapa/ement.el
-;; Version: 0.4.1
-;; Package-Requires: ((emacs "27.1") (map "2.1") (plz "0.2") (taxy "0.9") (taxy-magit-section "0.9") (svg-lib "0.2.5") (transient "0.3.7"))
+;; Version: 0.5.1
+;; Package-Requires: ((emacs "27.1") (map "2.1") (plz "0.2") (taxy "0.10") (taxy-magit-section "0.12.1") (svg-lib "0.2.5") (transient "0.3.7"))
 ;; Keywords: comm
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -82,8 +82,8 @@
   "Used to report progress while processing sync events.")
 
 (defvar ement-sync-callback-hook
-  '(ement--update-room-buffers ement--auto-sync ement-room-list-auto-update
-                               ement-taxy-auto-update)
+  '(ement--update-room-buffers ement--auto-sync ement-tabulated-room-list-auto-update
+                               ement-room-list-auto-update)
   "Hook run after `ement--sync-callback'.
 Hooks are called with one argument, the session that was
 synced.")
@@ -136,7 +136,7 @@ Writes the session file when Emacs is killed."
   :type 'boolean)
 
 (defcustom ement-after-initial-sync-hook
-  '(ement-list-rooms ement-view-initial-rooms ement--link-children ement--run-idle-timer)
+  '(ement-room-list--after-initial-sync ement-view-initial-rooms ement--link-children ement--run-idle-timer)
   "Hook run after initial sync.
 Run with one argument, the session synced."
   :type 'hook)
@@ -862,9 +862,12 @@ and `session' to the session.  Adds function to
                          ;; Only do this when ImageMagick is supported.
                          ;; FIXME: When requiring Emacs 27+, remove this (I guess?).
                          (setf (image-property image :type) 'imagemagick))
-                       ;; We set the room-avatar slot to a propertized string that displays
-                       ;; as the image.  This seems the most convenient thing to do.
-                       (setf (ement-room-avatar room) (propertize " " 'display image)))))))
+                       ;; We set the room-avatar slot to a propertized string that
+                       ;; displays as the image.  This seems the most convenient thing to
+                       ;; do.  We also unset the cached room-list-avatar so it can be
+                       ;; remade.
+                       (setf (ement-room-avatar room) (propertize " " 'display image)
+                             (alist-get 'room-list-avatar (ement-room-local room)) nil))))))
       ;; Unset avatar.
       (setf (ement-room-avatar room) nil
             (alist-get 'room-list-avatar (ement-room-local room)) nil))))
@@ -950,6 +953,11 @@ and `session' to the session.  Adds function to
         (setf (alist-get 'parents (ement-room-local child-room))
               (delete parent-room-id (alist-get 'parents (ement-room-local child-room))))))))
 
+(ement-defevent "m.room.canonical_alias"
+  (ignore session)
+  (pcase-let (((cl-struct ement-event (content (map alias))) event))
+    (setf (ement-room-canonical-alias room) alias)))
+
 (defun ement--link-children (session)
   "Link child rooms in SESSION.
 To be called after initial sync."
